Method: OSDNClient::Configuration#verify_ssl

Defined in:
lib/osdn-client/configuration.rb

#verify_ssltrue, false

Note:

Do NOT set it to false in production code, otherwise you would face multiple types of cryptographic attacks.

TLS/SSL setting Set this to false to skip verifying SSL certificate when calling API from https server. Default to true.



97
98
99
# File 'lib/osdn-client/configuration.rb', line 97

def verify_ssl
  @verify_ssl
end